<?php

include('bootstrap.php');

class patchInModuleDirTest extends PHPUnit_Framework_TestCase {

  public function testGetPatchesForProjectModule() {

    $fileSystem = $this->getMockBuilder('fileSystemInterface')->getMock();

    $fileSystem->expects($this->once())
      ->method('getPath')
      ->with('module', 'foo')
      ->will($this->returnValue('sites/all/modules/foo'));

    $fileSystem->expects($this->once())
      ->method('scanDirectory')
      ->with('sites/all/modules/foo', '/\.patch$/', array('recurse' => FALSE))
      ->will($this->returnValue(array(
        'sites/all/modules/foo/12345-12-do_things.patch' => array(
            'uri' => 'sites/all/modules/foo/12345-12-do_things.patch',
            'filename' => '12345-12-do_things.patch',
            'name' => '12345-12-do_things',
        ),
        'sites/all/modules/foo/12346-123-do_other_things.patch' => array(
          'uri' => 'sites/all/modules/foo/12346-123-do_other_things.patch',
          'filename' => '12346-123-do_other_things.patch',
          'name' => '12346-123-do_other_things',
        ),
      )));

    $patchDetector = new patchInModuleDir($fileSystem);

    $patches = $patchDetector->getPatchesForProject('module', 'foo');

    $this->assertEquals(count($patches), 2, 'Number of patches');
    $this->assertEquals($patches[0], '12345-12-do_things.patch', 'Patch filename 1');
    $this->assertEquals($patches[1], '12346-123-do_other_things.patch', 'Patch filename 2');
  }

  public function testGetPatchesForProjectCore() {

    $fileSystem = $this->getMockBuilder('fileSystemInterface')->getMock();

    $fileSystem->expects($this->never())
      ->method('getPath');

    $fileSystem->expects($this->once())
      ->method('scanDirectory')
      ->with(DRUPAL_ROOT, '/\.patch$/', array('recurse' => FALSE))
      ->will($this->returnValue(array(
        '12345-12-do_things.patch' => array(
          'uri' => '12345-12-do_things.patch',
          'filename' => '12345-12-do_things.patch',
          'name' => '12345-12-do_things',
        ),
        '12346-123-do_other_things.patch' => array(
          'uri' => '12346-123-do_other_things.patch',
          'filename' => '12346-123-do_other_things.patch',
          'name' => '12346-123-do_other_things',
        ),
      )));

    $patchDetector = new patchInModuleDir($fileSystem);

    $patches = $patchDetector->getPatchesForProject('core', 'system');

    $this->assertEquals(count($patches), 2, 'Number of patches');
    $this->assertEquals($patches[0], '12345-12-do_things.patch', 'Patch filename 1');
    $this->assertEquals($patches[1], '12346-123-do_other_things.patch', 'Patch filename 2');
  }
}